@@ -1,14 +1,10 @@
 
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 __common_alias__ = "nsbatwm"
 
-from napari.types import ImageData, LabelsData
-
 from napari_plugin_engine import napari_hook_implementation
-
 import numpy as np
 from scipy import ndimage as ndi
-
 from skimage.filters import threshold_otsu as sk_threshold_otsu, gaussian, sobel
 from skimage.segmentation import watershed
 from skimage.feature import peak_local_max
@@ -21,12 +17,11 @@ from skimage.measure import regionprops
 from skimage.segmentation import relabel_sequential
 from skimage.segmentation import clear_border
 from skimage.segmentation import expand_labels as sk_expand_labels
-
 from skimage import filters
 import scipy
 from scipy import ndimage
-import napari
 from napari_time_slicer import time_slicer
+from stackview import jupyter_displayable_output
 
 @napari_hook_implementation
 def napari_experimental_provide_function():
@@ -90,8 +85,9 @@ def _sobel_3d(image):
 
 
 @register_function(menu="Segmentation post-processing > Split touching objects (nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def split_touching_objects(binary:LabelsData, sigma: float = 3.5) -> LabelsData:
+def split_touching_objects(binary:"napari.types.LabelsData", sigma: float = 3.5) -> "napari.types.LabelsData":
     """
     Takes a binary image and draws cuts in the objects similar to the ImageJ watershed algorithm [1].
 
@@ -129,8 +125,9 @@ def split_touching_objects(binary:LabelsData, sigma: float = 3.5) -> LabelsData:
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Otsu et al 1979, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_otsu(image:ImageData) -> LabelsData:
+def threshold_otsu(image:"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Applies Otsu's threshold selection method to an intensity image and returns a binary image with pixels==1 where
     intensity is above the determined threshold.
@@ -147,8 +144,9 @@ def threshold_otsu(image:ImageData) -> LabelsData:
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Yen et al 1995, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_yen(image : napari.types.ImageData) -> napari.types.LabelsData:
+def threshold_yen(image :"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Binarize an image using Yen's method.
 
@@ -168,8 +166,9 @@ def threshold_yen(image : napari.types.ImageData) -> napari.types.LabelsData:
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Isodata, Ridler et al 1978, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_isodata(image : napari.types.ImageData) -> napari.types.LabelsData:
+def threshold_isodata(image :"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Binarize an image using the IsoData / Ridler's method.
     The method is similar to ImageJ's "default" threshold.
@@ -191,8 +190,9 @@ def threshold_isodata(image : napari.types.ImageData) -> napari.types.LabelsData
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Li et al 1993, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_li(image : napari.types.ImageData) -> napari.types.LabelsData:
+def threshold_li(image:"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Binarize an image using Li's method method.
 
@@ -212,8 +212,9 @@ def threshold_li(image : napari.types.ImageData) -> napari.types.LabelsData:
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Ridler et al 1978, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_mean(image : napari.types.ImageData) -> napari.types.LabelsData:
+def threshold_mean(image :"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Binarize an image using the Mean method.
 
@@ -233,8 +234,9 @@ def threshold_mean(image : napari.types.ImageData) -> napari.types.LabelsData:
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Mean, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_minimum(image : napari.types.ImageData) -> napari.types.LabelsData:
+def threshold_minimum(image :"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Binarize an image using the Minimum method.
 
@@ -254,8 +256,9 @@ def threshold_minimum(image : napari.types.ImageData) -> napari.types.LabelsData
 
 
 @register_function(menu="Segmentation / binarization > Threshold (Triangle method, Zack et al 1977, scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def threshold_triangle(image : napari.types.ImageData) -> napari.types.LabelsData:
+def threshold_triangle(image:"napari.types.ImageData") -> "napari.types.LabelsData":
     """
     Binarize an image using the Triangle method.
 
@@ -275,8 +278,9 @@ def threshold_triangle(image : napari.types.ImageData) -> napari.types.LabelsDat
 
 
 @register_function(menu="Filtering / noise removal > Gaussian (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def gaussian_blur(image:ImageData, sigma: float = 1) -> ImageData:
+def gaussian_blur(image:"napari.types.ImageData", sigma: float = 1) -> "napari.types.ImageData":
     """
     Applies a Gaussian blur to an image with a defined sigma. Useful for denoising.
     """
@@ -284,8 +288,9 @@ def gaussian_blur(image:ImageData, sigma: float = 1) -> ImageData:
 
 
 @register_function(menu="Filtering / edge enhancement > Gaussian Laplace (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def gaussian_laplace(image: napari.types.ImageData, sigma: float = 2) -> napari.types.ImageData:
+def gaussian_laplace(image:"napari.types.ImageData", sigma: float = 2)-> "napari.types.ImageData":
     """
     Apply Laplace filter for edge detection / edge enhancement after applying a Gaussian-blur
 
@@ -308,8 +313,9 @@ def gaussian_laplace(image: napari.types.ImageData, sigma: float = 2) -> napari.
 
 
 @register_function(menu="Filtering / noise removal > Median (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def median_filter(image: napari.types.ImageData, radius: float = 2) -> napari.types.ImageData:
+def median_filter(image:"napari.types.ImageData", radius: float = 2)-> "napari.types.ImageData":
     """
     The median-filter allows removing noise from images. While locally averaging intensity, it
     is an edge-preserving filter.
@@ -321,8 +327,9 @@ def median_filter(image: napari.types.ImageData, radius: float = 2) -> napari.ty
 
 
 @register_function(menu="Filtering / noise removal > Percentile (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def percentile_filter(image: napari.types.ImageData, percentile : float = 50, radius: float = 2) -> napari.types.ImageData:
+def percentile_filter(image:"napari.types.ImageData", percentile : float = 50, radius: float = 2)-> "napari.types.ImageData":
     """The percentile filter is similar to the median-filter but it allows specifying the percentile.
     The percentile-filter with percentile==50 is equal to the median-filter.
     """
@@ -330,8 +337,9 @@ def percentile_filter(image: napari.types.ImageData, percentile : float = 50, ra
 
 
 @register_function(menu="Filtering / background removal > White top-hat (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def white_tophat(image: napari.types.ImageData, radius: float = 2) -> napari.types.ImageData:
+def white_tophat(image:"napari.types.ImageData", radius: float = 2)-> "napari.types.ImageData":
     """
     The white top-hat filter removes bright regions from an image showing black islands.
 
@@ -341,8 +349,9 @@ def white_tophat(image: napari.types.ImageData, radius: float = 2) -> napari.typ
 
 
 @register_function(menu="Filtering / background removal > Black top-hat (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def black_tophat(image: napari.types.ImageData, radius: float = 2) -> napari.types.ImageData:
+def black_tophat(image:"napari.types.ImageData", radius: float = 2)-> "napari.types.ImageData":
     """
     The black top-hat filter removes bright regions from an image showing black islands.
     """
@@ -350,8 +359,9 @@ def black_tophat(image: napari.types.ImageData, radius: float = 2) -> napari.typ
 
 
 @register_function(menu="Filtering / background removal > Minimum (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def minimum_filter(image: napari.types.ImageData, radius: float = 2) -> napari.types.ImageData:
+def minimum_filter(image:"napari.types.ImageData", radius: float = 2)-> "napari.types.ImageData":
     """
     Local minimum filter
 
@@ -361,8 +371,9 @@ def minimum_filter(image: napari.types.ImageData, radius: float = 2) -> napari.t
 
 
 @register_function(menu="Filtering / background removal > Maximum (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def maximum_filter(image: napari.types.ImageData, radius: float = 2) -> napari.types.ImageData:
+def maximum_filter(image:"napari.types.ImageData", radius: float = 2)-> "napari.types.ImageData":
     """
     Local maximum filter
 
@@ -373,8 +384,9 @@ def maximum_filter(image: napari.types.ImageData, radius: float = 2) -> napari.t
 
 
 @register_function(menu="Filtering / edge enhancement > Morphological Gradient (scipy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def morphological_gradient(image: napari.types.ImageData, radius: float = 2) -> napari.types.ImageData:
+def morphological_gradient(image:"napari.types.ImageData", radius: float = 2)-> "napari.types.ImageData":
     """
     Apply gradient filter (similar to the Sobel operator) for edge detection / edge enhancement.
     This is similar to applying a Gaussian-blur to an image and afterwards the gradient operator
@@ -398,8 +410,9 @@ def morphological_gradient(image: napari.types.ImageData, radius: float = 2) ->
 
 
 @register_function(menu="Filtering / background removal > Rolling ball (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def subtract_background(image:ImageData, rolling_ball_radius: float = 5) -> ImageData:
+def subtract_background(image:"napari.types.ImageData", rolling_ball_radius: float = 5) -> "napari.types.ImageData":
     """
     Subtract background in an image using the rolling-ball algorithm.
 
@@ -412,8 +425,9 @@ def subtract_background(image:ImageData, rolling_ball_radius: float = 5) -> Imag
 
 
 @register_function(menu="Segmentation post-processing > Invert binary image (nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def binary_invert(binary_image:LabelsData) -> LabelsData:
+def binary_invert(binary_image:"napari.types.LabelsData") -> "napari.types.LabelsData":
     """
     Inverts a binary image.
     """
@@ -421,8 +435,9 @@ def binary_invert(binary_image:LabelsData) -> LabelsData:
 
 
 @register_function(menu="Segmentation / labeling > Connected component labeling (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def connected_component_labeling(binary_image: LabelsData, exclude_on_edges: bool = False) -> LabelsData:
+def connected_component_labeling(binary_image: "napari.types.LabelsData", exclude_on_edges: bool = False) -> "napari.types.LabelsData":
     """
     Takes a binary image and produces a label image with all separated objects labeled with
     different integer numbers.
@@ -441,8 +456,9 @@ def connected_component_labeling(binary_image: LabelsData, exclude_on_edges: boo
 
 
 @register_function(menu="Segmentation post-processing > Remove labeled objects at the image border (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def remove_labels_on_edges(label_image: LabelsData) -> LabelsData:
+def remove_labels_on_edges(label_image: "napari.types.LabelsData") -> "napari.types.LabelsData":
     """
     Takes a label image and removes objects that touch the image border.
     The remaining labels are relabeled sequentially.
@@ -458,8 +474,9 @@ def remove_labels_on_edges(label_image: LabelsData) -> LabelsData:
 
 
 @register_function(menu="Segmentation post-processing > Expand labels (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def expand_labels(label_image: LabelsData, distance: float = 1) -> LabelsData:
+def expand_labels(label_image: "napari.types.LabelsData", distance: float = 1) -> "napari.types.LabelsData":
     """
     Takes a label image and makes labels larger up to a given radius (distance).
     Labels will not overwrite each other while expanding. This operation is also known as label dilation.
@@ -473,8 +490,9 @@ def expand_labels(label_image: LabelsData, distance: float = 1) -> LabelsData:
 
 
 @register_function(menu="Segmentation / labeling > Voronoi-Otsu-labeling (nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def voronoi_otsu_labeling(image:ImageData, spot_sigma: float = 2, outline_sigma: float = 2) -> LabelsData:
+def voronoi_otsu_labeling(image:"napari.types.ImageData", spot_sigma: float = 2, outline_sigma: float = 2) -> "napari.types.LabelsData":
     """Voronoi-Otsu-Labeling is a segmentation algorithm for blob-like structures such as nuclei and
     granules with high signal intensity on low-intensity background.
 
@@ -515,8 +533,9 @@ def voronoi_otsu_labeling(image:ImageData, spot_sigma: float = 2, outline_sigma:
 
 
 @register_function(menu="Segmentation / labeling > Gauss-Otsu-labeling (nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def gauss_otsu_labeling(image:ImageData, outline_sigma: float = 2) -> LabelsData:
+def gauss_otsu_labeling(image:"napari.types.ImageData", outline_sigma: float = 2) -> "napari.types.LabelsData":
     """Gauss-Otsu-Labeling can be used to segment objects such as nuclei with bright intensity on
     low intensity background images.
 
@@ -543,8 +562,9 @@ def gauss_otsu_labeling(image:ImageData, outline_sigma: float = 2) -> LabelsData
 
 
 @register_function(menu="Segmentation / labeling > Seeded watershed (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def seeded_watershed(membranes:ImageData, labeled_nuclei:LabelsData) -> LabelsData:
+def seeded_watershed(membranes:"napari.types.ImageData", labeled_nuclei:"napari.types.LabelsData") -> "napari.types.LabelsData":
     """
     Takes a image with bright (high intensity) membranes and an image with labeled objects such as nuclei.
     The latter serves as seeds image for a watershed labeling.
@@ -560,8 +580,9 @@ def seeded_watershed(membranes:ImageData, labeled_nuclei:LabelsData) -> LabelsDa
     return cells
 
 @register_function(menu="Segmentation / labeling > Seeded watershed with mask (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def seeded_watershed_with_mask(membranes:ImageData, labeled_nuclei:LabelsData, mask:LabelsData) -> LabelsData:
+def seeded_watershed_with_mask(membranes:"napari.types.ImageData", labeled_nuclei:"napari.types.LabelsData", mask:"napari.types.LabelsData") -> "napari.types.LabelsData":
     """
     Takes a image with bright (high intensity) membranes, an image with labeled objects such as nuclei and a mask imge, e.g. a binary image of the entire tissue of interest.
     The labeled nuclei serve as seeds image for a watershed labeling and the mask for constrainting the flooding.
@@ -579,8 +600,9 @@ def seeded_watershed_with_mask(membranes:ImageData, labeled_nuclei:LabelsData, m
 
 
 @register_function(menu="Segmentation / labeling > Seeded watershed using local minima as seeds (nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def local_minima_seeded_watershed(image:ImageData, spot_sigma: float = 10, outline_sigma: float = 0) -> LabelsData:
+def local_minima_seeded_watershed(image:"napari.types.ImageData", spot_sigma: float = 10, outline_sigma: float = 0) -> "napari.types.LabelsData":
     """
     Segment cells in images with fluorescently marked membranes.
 
@@ -608,8 +630,9 @@ def local_minima_seeded_watershed(image:ImageData, spot_sigma: float = 10, outli
 
 
 @register_function(menu="Segmentation / labeling > Seeded watershed using local minima as seeds and an intensity threshold (nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def thresholded_local_minima_seeded_watershed(image:ImageData, spot_sigma: float = 3, outline_sigma: float = 0, minimum_intensity: float = 500) -> LabelsData:
+def thresholded_local_minima_seeded_watershed(image:"napari.types.ImageData", spot_sigma: float = 3, outline_sigma: float = 0, minimum_intensity: float = 500) -> "napari.types.LabelsData":
     """
     Segment cells in images with marked membranes that have a high signal intensity.
 
@@ -633,29 +656,33 @@ def thresholded_local_minima_seeded_watershed(image:ImageData, spot_sigma: float
     return new_labels
 
 @register_function(menu="Image math > Sum images (numpy, nsbatwm)", factor1={'min': -1000000, 'max': 1000000}, factor2={'min': -1000000, 'max': 1000000})
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def sum_images(image1: ImageData, image2: ImageData, factor1: float = 1, factor2: float = 1) -> ImageData:
+def sum_images(image1: "napari.types.ImageData", image2: "napari.types.ImageData", factor1: float = 1, factor2: float = 1) -> "napari.types.ImageData":
     """Add two images"""
     return image1 * factor1 + image2 * factor2
 
 
 @register_function(menu="Image math > Multiply images (numpy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def multiply_images(image1: ImageData, image2: ImageData) -> ImageData:
+def multiply_images(image1: "napari.types.ImageData", image2: "napari.types.ImageData") -> "napari.types.ImageData":
     """Multiply two images"""
     return image1 * image2
 
 
 @register_function(menu="Image math > Divide images (numpy, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def divide_images(image1: ImageData, image2: ImageData) -> ImageData:
+def divide_images(image1: "napari.types.ImageData", image2: "napari.types.ImageData") -> "napari.types.ImageData":
     """Divide one image by another"""
     return image1 / image2
 
 
 @register_function(menu="Image math > Invert image (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def invert_image(image: ImageData) -> ImageData:
+def invert_image(image: "napari.types.ImageData") -> "napari.types.ImageData":
     """Invert an image. The exact math behind depends on the image type.
 
     See also
@@ -667,8 +694,9 @@ def invert_image(image: ImageData) -> ImageData:
 
 
 @register_function(menu="Segmentation post-processing > Skeletonize (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
 @time_slicer
-def skeletonize(image: LabelsData) -> LabelsData:
+def skeletonize(image: "napari.types.LabelsData") -> "napari.types.LabelsData":
     """
     Skeletonize labeled objects in an image. This can be useful to reduce objects such as neurons, roots and vessels
     with variable thickness to single pixel lines for further analysis.
@@ -689,7 +717,7 @@ def skeletonize(image: LabelsData) -> LabelsData:
 
 
 @register_function(menu="Utilities > Manually merge labels (nsbatwm)")
-def Manually_merge_labels(labels_layer: napari.layers.Labels, points_layer: napari.layers.Points, viewer : napari.Viewer):
+def Manually_merge_labels(labels_layer: "napari.layers.Labels", points_layer: "napari.layers.Points", viewer : "napari.Viewer"):
     if points_layer is None:
         points_layer = viewer.add_points([])
         points_layer.mode = 'ADD'
@@ -709,7 +737,7 @@ def Manually_merge_labels(labels_layer: napari.layers.Labels, points_layer: napa
     points_layer.data = []
 
 @register_function(menu="Utilities > Manually split labels (nsbatwm)")
-def Manually_split_labels(labels_layer: napari.layers.Labels, points_layer: napari.layers.Points, viewer: napari.Viewer):
+def Manually_split_labels(labels_layer: "napari.layers.Labels", points_layer: "napari.layers.Points", viewer: "napari.Viewer"):
     if points_layer is None:
         points_layer = viewer.add_points([])
         points_layer.mode = 'ADD'
@@ -746,3 +774,32 @@ def Manually_split_labels(labels_layer: napari.layers.Labels, points_layer: napa
     points_layer.data = []
 
 
+@register_function(menu="Filtering / noise removal > Butterworth (scikit-image, nsbatwm)")
+@jupyter_displayable_output(library_name='nsbatwm', help_url='https://www.napari-hub.org/plugins/napari-segment-blobs-and-things-with-membranes')
+@time_slicer
+def butterworth(image: "napari.types.ImageData", cutoff_frequency_ratio: float = 0.005, high_pass: bool = False,
+                order: float = 2) -> "napari.types.ImageData":
+    """Apply a Butterworth filter to enhance high or low frequency features.
+
+    This filter is defined in the Fourier domain.
+
+    Parameters
+    ----------
+    image : (M[, N[, ..., P]][, C]) ndarray
+        Input image.
+    cutoff_frequency_ratio : float, optional
+        Determines the position of the cut-off relative to the shape of the
+        FFT.
+    high_pass : bool, optional
+        Whether to perform a high pass filter. If False, a low pass filter is
+        performed.
+    order : float, optional
+        Order of the filter which affects the slope near the cut-off. Higher
+        order means steeper slope in frequency space.
+
+    See also
+    --------
+    ..[0] https://scikit-image.org/docs/stable/api/skimage.filters.html#skimage.filters.butterworth
+    """
+    from skimage.filters import butterworth as skimage_butterworth
+    return skimage_butterworth(image, cutoff_frequency_ratio, high_pass, order)
